

# Get ngrok tunnel info
Easy and fast tool written in **python 3** to get info about running ngrok tunnel. Supports **HTTPS** and **TCP**
___
### ‎

## Instalation
* ### Windows / macOS
	Run `python3 -m pip install ngrok_info`
	
* ### Linux
	Run `python3 -m pip install ngrok_info`
### ‎

## Usage
* ### Windows / macOS
	Add to your script `import ngrok_info`
	                   `ngrok-info.get`
	
* ### Linux
	Add to your script `import ngrok_info`
		               `ngrok-info.get`

### ‎
## FAQ
* ### Error: wrong tunnel name specified or no tunnel is running
	Check if ngrok is really running on your computer.
	If yes, check if you have correctly specified [tunnel name](https://ngrok.com/docs#tunnel-definitions). You need to specify it only, if you are using [config file](https://ngrok.com/docs#config-default-location) to specify tunnel preset. If you've checked everything, but it's still not working, contact [us on Discord](https://discord.gg/agREa6Dh3r) or [open issue](https://github.com/HexagonCore/get-ngrok-tunnel-info/issues/new/choose).
### ‎


Do you like this? Hit that ⭐!                                
Use the star button as way to show us, that it works              
Fork and pull requests are welcome of course
